@@ -2,7 +2,7 @@
  * Dynamic compose view.
  *
  * @author     Michael Slusarz <slusarz@horde.org>
- * @copyright  2005-2014 Horde LLC
+ * @copyright  2005-2015 Horde LLC
  * @license    GPL-2 (http://www.horde.org/licenses/gpl)
  */
 
@@ -126,7 +126,8 @@ var DimpCompose = {
             }
         });
         if (identity.bcc) {
-            $('bcc').setValue(($F('bcc') ? $F('bcc') + ', ' : '') + identity.bcc);
+            $('bcc').setValue(($F('bcc') ? $F('bcc') + ', ' : '') + identity.bcc)
+                .fire('AutoComplete:reset');
             this.toggleCC('bcc');
         }
         this.setSaveSentMail(identity.sm_save);
@@ -193,7 +194,7 @@ var DimpCompose = {
         }
 
         if (!l) {
-            l = k.opts.data.find(function(f) {
+            l = (k.opts.data || []).find(function(f) {
                 return f.v == s;
             });
 
@@ -256,7 +257,7 @@ var DimpCompose = {
         case 'saveDraft':
         case 'saveTemplate':
             // Don't send/save until uploading is completed.
-            if ($('upload_wait').visible()) {
+            if ($('upload_wait') && $('upload_wait').visible()) {
                 (function() { if (this.disabled) { this.uniqueSubmit(action); } }).bind(this).delay(0.25);
                 return;
             }
@@ -581,8 +582,13 @@ var DimpCompose = {
             this.rte = new IMP_Editor('composeMessage', config);
 
             this.rte.editor.on('getData', function(evt) {
-                var elt = new Element('SPAN').insert(evt.data.dataValue),
-                    elts = elt.select('IMG[dropatc_id]');
+                var elt = new Element('SPAN'), elts;
+
+                /* Don't use prototype's insert() since we don't want any
+                 * scripts that may exist in the text data to be eval'd. */
+                elt.innerHTML = evt.data.dataValue;
+                elts = elt.select('IMG[dropatc_id]');
+
                 if (elts.size()) {
                     elts.invoke('writeAttribute', 'dropatc_id', null);
                     elts.invoke('writeAttribute', 'src', null);
@@ -1378,6 +1384,8 @@ var DimpCompose = {
 
     onDomLoad: function()
     {
+        var tmp;
+
         /* Initialize redirect elements. */
         if (DimpCore.conf.redirect) {
             $('redirect').observe('submit', Event.stop);
@@ -1417,11 +1425,11 @@ var DimpCompose = {
             callback: this.uniqueSubmitCallback.bind(this)
         });
 
-        if ($H(DimpCore.context.ctx_atc).size()) {
-            $('atcdrop').observe('DragHandler:drop', function(e) {
+        if ((tmp = $('atcdrop'))) {
+            tmp.observe('DragHandler:drop', function(e) {
                 this.uploadAttachmentAjax(e.memo);
             }.bindAsEventListener(this));
-            DragHandler.dropelt = $('atcdrop');
+            DragHandler.dropelt = tmp;
             DragHandler.droptarget = $('atcdiv');
             DragHandler.hoverclass = 'atcdrop_over';
             DimpCore.addPopdown($('upload'), 'atc', {
@@ -1547,7 +1555,6 @@ document.observe('IMP_Editor:ready', function(e) {
 document.observe('IMP_Editor:dataReady', function(e) {
     if (e.memo.name == 'composeMessage') {
         this.RTELoading(false);
-        e.memo.focus();
         this.resizeMsgArea();
     }
 }.bindAsEventListener(DimpCompose));
