@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2013-2015 Horde LLC
+ * @copyright 2013-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -15,14 +15,14 @@
  * The pretty AJAX autocompleter. Extended in IMP to use the IMP-specific
  * autocompleter library instead of the Horde_Core library.
  *
- * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2015 Horde LLC
+ * @copyright 2013-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -40,7 +40,7 @@ extends Horde_Core_Ajax_Imple_AutoCompleter_Ajax
                 'boxClass' => 'hordeACBox impACBox',
                 'boxClassFocus' => 'impACBoxFocus',
                 'deleteIcon' => strval(Horde_Themes::img('delete-small.png')),
-                'displayFilter' => 'new Function("t", "return t.sub(/<[^>]*>$/, \"\").strip().escapeHTML()")',
+                'displayFilter' => 'new Function("t", "return t.sub(/<[^>]*(?:>|\\.{3})$/, \"\").strip().escapeHTML()")',
                 'growingInputClass' => 'hordeACTrigger impACTrigger',
                 'listClass' => 'hordeACList impACList',
                 'processValueCallback' => 'ImpComposeBase.autocompleteValue.bind(ImpComposeBase)',
