@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2006-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2006-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2006-2015 Horde LLC
+ * @copyright 2006-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2006-2015 Horde LLC
+ * @copyright 2006-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -184,7 +184,7 @@ class IMP_Compose_Ui
 
         case 'text':
             return $GLOBALS['injector']->getInstance('Horde_Core_Factory_TextFilter')->filter($data, 'Html2text', array(
-                'wrap' => false
+                'width' => 0
             ));
         }
     }
