@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2002-2015 Horde LLC
+ * @copyright 2002-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -20,7 +20,7 @@
  * @author    Michael Slusarz <slusarz@horde.org>
  * @author    Gunnar Wrobel <wrobel@pardus.de>
  * @category  Horde
- * @copyright 2002-2015 Horde LLC
+ * @copyright 2002-2016 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -382,6 +382,7 @@ class IMP_Mime_Viewer_Itip extends Horde_Mime_Viewer_Base
             $view->start = is_array($start)
                 ? strftime($prefs->getValue('date_format'), mktime(0, 0, 0, $start['month'], $start['mday'], $start['year']))
                 : strftime($prefs->getValue('date_format'), $start) . ' ' . date($prefs->getValue('twentyFour') ? ' G:i' : ' g:i a', $start);
+            $start_date = new Horde_Date($start);
         } catch (Horde_Icalendar_Exception $e) {
             $start = null;
         }
@@ -419,7 +420,7 @@ class IMP_Mime_Viewer_Itip extends Horde_Mime_Viewer_Base
             $rrule = array();
         }
         if (!is_array($rrule)) {
-            $recurrence = new Horde_Date_Recurrence(new Horde_Date($view->start));
+            $recurrence = new Horde_Date_Recurrence($start_date);
             if (strpos($rrule, '=') !== false) {
                 $recurrence->fromRRule20($rrule);
             } else {
