@@ -1,6 +1,6 @@
 <form method="post" id="messages" name="messages" action="<?php echo $this->mailbox_url ?>">
  <?php echo $this->hiddenFieldTag('mailbox', $this->mailbox) ?>
- <?php echo $this->hiddenFieldTag('mailbox_token', $this->mailbox_token) ?>
+ <?php echo $this->hiddenFieldTag('token', $this->token) ?>
  <?php echo $this->hiddenFieldTag('mpage', $this->page) ?>
  <?php echo $this->hiddenFieldTag('actionID') ?>
  <?php echo $this->hiddenFieldTag('targetMbox') ?>
